@@ -53,6 +53,7 @@ from lollypop.database_tracks import TracksDatabase
 from lollypop.notification import NotificationManager
 from lollypop.playlists import Playlists
 from lollypop.objects import Album, Track
+from lollypop.helper_task import TaskHelper
 from lollypop.collectionscanner import CollectionScanner
 
 
@@ -85,7 +86,13 @@ class Application(Gtk.Application):
         GLib.setenv("PULSE_PROP_media.role", "music", True)
         GLib.setenv("PULSE_PROP_application.icon_name",
                     "org.gnome.Lollypop", True)
-
+        # Fix proxy for python
+        proxy = GLib.environ_getenv(GLib.get_environ(), "all_proxy")
+        if proxy is not None and proxy.startswith("socks://"):
+            proxy = proxy.replace("socks://", "socks4://")
+            from os import environ
+            environ["all_proxy"] = proxy
+            environ["ALL_PROXY"] = proxy
         # Ideally, we will be able to delete this once Flatpak has a solution
         # for SSL certificate management inside of applications.
         if GLib.file_test("/app", GLib.FileTest.EXISTS):
@@ -178,6 +185,7 @@ class Application(Gtk.Application):
         self.art = Art()
         self.notify = NotificationManager()
         self.art.update_art_size()
+        self.task_helper = TaskHelper()
         if self.settings.get_value("artist-artwork"):
             GLib.timeout_add(5000, self.art.cache_artists_info)
         # Load lastfm if support available
@@ -219,6 +227,7 @@ class Application(Gtk.Application):
             Quit Lollypop
             @param vacuum as bool
         """
+        self.window.container.save_internals()
         if self.settings.get_value("save-state"):
             self.window.container.save_view_state()
         # Then vacuum db
