@@ -132,9 +132,8 @@ class CollectionScanner(GObject.GObject, TagReader):
                 else:
                     files.append(f)
             except Exception as e:
-                Logger.error("""CollectionScanner::
-                             __get_objects_for_uris(): %s""" % e)
-                return ([], [])
+                Logger.error("CollectionScanner::__get_objects_for_uris(): %s"
+                             % e)
         for f in files:
             try:
                 if is_pls(f):
@@ -142,11 +141,11 @@ class CollectionScanner(GObject.GObject, TagReader):
                 elif is_audio(f):
                     tracks.append(f.get_uri())
                 else:
-                    Logger.debug("""%s not detected
-                                 as a music file""" % f.get_uri())
+                    Logger.debug("%s not detected as a music file" %
+                                 f.get_uri())
             except Exception as e:
-                Logger.error("""CollectionScanner::
-                             __get_objects_for_uris(): %s""" % e)
+                Logger.error("CollectionScanner::__get_objects_for_uris(): %s"
+                             % e)
         return (tracks, track_dirs)
 
     def __update_progress(self, current, total):
@@ -192,12 +191,13 @@ class CollectionScanner(GObject.GObject, TagReader):
                     self.__inotify.add_monitor(d)
 
         i = 0
-        # Look for new files/modified files
+        # Look for new files/modified file
+        SqlCursor.add(App().db)
         try:
             to_add = []
-            SqlCursor.add(App().db)
             for uri in new_tracks:
                 if self.__thread is None:
+                    SqlCursor.remove(App().db)
                     return
                 try:
                     GLib.idle_add(self.__update_progress, i, count)
@@ -247,6 +247,7 @@ class CollectionScanner(GObject.GObject, TagReader):
                     i += 1
                     GLib.idle_add(self.__update_progress, i, count)
                     self.__del_from_db(uri)
+                    SqlCursor.allow_thread_execution(App().db)
             # Add files to db
             for (uri, mtime) in to_add:
                 try:
@@ -258,9 +259,10 @@ class CollectionScanner(GObject.GObject, TagReader):
                 except Exception as e:
                     Logger.error("CollectionScanner::__scan(add): %s, %s" %
                                  (e, uri))
-            SqlCursor.remove(App().db)
         except Exception as e:
             Logger.error("CollectionScanner::__scan(): %s" % e)
+        SqlCursor.commit(App().db)
+        SqlCursor.remove(App().db)
         GLib.idle_add(self.__finish, modifications and saved)
         if not saved:
             self.__play_new_tracks(new_tracks)
@@ -329,8 +331,7 @@ class CollectionScanner(GObject.GObject, TagReader):
 
         Logger.debug("CollectionScanner::add2db(): "
                      "Add album artists %s" % album_artists)
-        (album_artist_ids,
-         new_artist_ids) = self.add_album_artists(album_artists, aa_sortnames)
+        album_artist_ids = self.add_album_artists(album_artists, aa_sortnames)
 
         # User does not want compilations
         if self.__disable_compilations and not album_artist_ids:
@@ -345,13 +346,12 @@ class CollectionScanner(GObject.GObject, TagReader):
 
         Logger.debug("CollectionScanner::add2db(): Add album: "
                      "%s, %s" % (album_name, album_artist_ids))
-        (album_id, new_album) = self.add_album(album_name, mb_album_id,
-                                               album_artist_ids,
-                                               uri, loved, album_pop,
-                                               album_rate, mtime)
+        album_id = self.add_album(album_name, mb_album_id,
+                                  album_artist_ids,
+                                  uri, loved, album_pop,
+                                  album_rate, mtime)
 
-        (genre_ids,
-         new_genre_ids) = self.add_genres(genres)
+        genre_ids = self.add_genres(genres)
 
         # Add track to db
         Logger.debug("CollectionScanner::add2db(): Add track")
@@ -360,18 +360,14 @@ class CollectionScanner(GObject.GObject, TagReader):
                                     album_id, year, timestamp, track_pop,
                                     track_rate, track_ltime, mtime,
                                     mb_track_id)
-
+        SqlCursor.commit(App().db)
         Logger.debug("CollectionScanner::add2db(): Update track")
         self.__update_track(track_id, artist_ids, genre_ids)
         Logger.debug("CollectionScanner::add2db(): Update album")
         self.__update_album(album_id, album_artist_ids,
                             genre_ids, year, timestamp)
-        if new_album:
-            SqlCursor.commit(App().db)
-        for genre_id in new_genre_ids:
+        for genre_id in genre_ids:
             GLib.idle_add(self.emit, "genre-updated", genre_id, True)
-        for artist_id in new_artist_ids:
-            GLib.idle_add(self.emit, "artist-updated", artist_id, True)
         return track_id
 
     def __del_from_db(self, uri):
