@@ -54,7 +54,7 @@ class TracksDatabase:
             @return inserted rowid as int
             @warning: commit needed
         """
-        with SqlCursor(App().db) as sql:
+        with SqlCursor(App().db, True) as sql:
             result = sql.execute(
                 "INSERT INTO tracks (name, uri, duration, tracknumber,\
                 discnumber, discname, album_id,\
@@ -84,7 +84,7 @@ class TracksDatabase:
             @param artist id as int
             @warning: commit needed
         """
-        with SqlCursor(App().db) as sql:
+        with SqlCursor(App().db, True) as sql:
             artists = self.get_artist_ids(track_id)
             if artist_id not in artists:
                 sql.execute("INSERT INTO "
@@ -98,7 +98,7 @@ class TracksDatabase:
             @param genre id as int
             @warning: commit needed
         """
-        with SqlCursor(App().db) as sql:
+        with SqlCursor(App().db, True) as sql:
             genres = self.get_genre_ids(track_id)
             if genre_id not in genres:
                 sql.execute("INSERT INTO\
@@ -283,7 +283,7 @@ class TracksDatabase:
             @param Track id as int
             @param uri as string
         """
-        with SqlCursor(App().db) as sql:
+        with SqlCursor(App().db, True) as sql:
             sql.execute("UPDATE tracks SET uri=?\
                          WHERE rowid=?",
                         (uri, track_id))
@@ -296,7 +296,7 @@ class TracksDatabase:
             @param Track id as int
             @param rate as int
         """
-        with SqlCursor(App().db) as sql:
+        with SqlCursor(App().db, True) as sql:
             sql.execute("UPDATE tracks SET rate=?\
                          WHERE rowid=?",
                         (rate, track_id))
@@ -460,7 +460,7 @@ class TracksDatabase:
             @param Track id as int
             @param duration as int
         """
-        with SqlCursor(App().db) as sql:
+        with SqlCursor(App().db, True) as sql:
             sql.execute("UPDATE tracks\
                          SET duration=?\
                          WHERE rowid=?", (duration, track_id,))
@@ -557,7 +557,7 @@ class TracksDatabase:
             @param track id as int
             @raise sqlite3.OperationalError on db update
         """
-        with SqlCursor(App().db) as sql:
+        with SqlCursor(App().db, True) as sql:
             result = sql.execute("SELECT popularity from tracks WHERE rowid=?",
                                  (track_id,))
             pop = result.fetchone()
@@ -575,7 +575,7 @@ class TracksDatabase:
             @param track id as int
             @param time as int
         """
-        with SqlCursor(App().db) as sql:
+        with SqlCursor(App().db, True) as sql:
             sql.execute("UPDATE tracks set ltime=? WHERE rowid=?",
                         (time, track_id))
 
@@ -603,31 +603,6 @@ class TracksDatabase:
                                   ORDER BY ltime DESC LIMIT 100")
             return list(itertools.chain(*result))
 
-    def get_persistent(self, track_id):
-        """
-            Return track persistent
-            @param track id as int
-            @return int
-        """
-        with SqlCursor(App().db) as sql:
-            result = sql.execute("SELECT rowid FROM tracks\
-                                  WHERE persistent=?", (track_id,))
-            v = result.fetchone()
-            if v is not None:
-                return v[0]
-            return 0
-
-    def set_persistent(self, track_id, persistent):
-        """
-            Set track persistent
-            @param track id as int
-            @param persistent as int
-        """
-        with SqlCursor(App().db) as sql:
-            sql.execute("UPDATE tracks\
-                         SET persistent=?\
-                         WHERE rowid=?", (persistent, track_id,))
-
     def get_randoms(self):
         """
             Return random tracks
@@ -645,7 +620,7 @@ class TracksDatabase:
             @param track id as int
             @param popularity as int
         """
-        with SqlCursor(App().db) as sql:
+        with SqlCursor(App().db, True) as sql:
             try:
                 sql.execute("UPDATE tracks set popularity=? WHERE rowid=?",
                             (popularity, track_id))
@@ -713,7 +688,7 @@ class TracksDatabase:
             @param track_id as int
             @warning commit needed
         """
-        with SqlCursor(App().db) as sql:
+        with SqlCursor(App().db, True) as sql:
             sql.execute("DELETE FROM track_artists\
                          WHERE track_id = ?", (track_id,))
             sql.execute("DELETE FROM track_genres\
@@ -758,7 +733,7 @@ class TracksDatabase:
             Remove track
             @param track id as int
         """
-        with SqlCursor(App().db) as sql:
+        with SqlCursor(App().db, True) as sql:
             sql.execute("DELETE FROM track_genres\
                          WHERE track_id=?", (track_id,))
             sql.execute("DELETE FROM track_artists\
