@@ -59,8 +59,8 @@ class FullScreen(Gtk.Window, InformationController,
         widget = builder.get_object("widget")
         grid = builder.get_object("grid")
         self._play_btn = builder.get_object("play_btn")
-        self._next_btn = builder.get_object("next_btn")
-        self._prev_btn = builder.get_object("prev_btn")
+        self._next_button = builder.get_object("next_btn")
+        self._prev_button = builder.get_object("prev_btn")
         self._play_image = builder.get_object("play_image")
         self._pause_image = builder.get_object("pause_image")
         close_btn = builder.get_object("close_btn")
