@@ -16,13 +16,14 @@ from gettext import gettext as _
 
 from lollypop.view_tracks import TracksView
 from lollypop.view import LazyLoadingView
+from lollypop.art import AlbumArtHelper
 from lollypop.objects import Album
 from lollypop.logger import Logger
 from lollypop.define import ArtSize, App, ResponsiveType, Shuffle
 from lollypop.controller_view import ViewController
 
 
-class AlbumRow(Gtk.ListBoxRow, TracksView):
+class AlbumRow(Gtk.ListBoxRow, TracksView, AlbumArtHelper):
     """
         Album row
     """
@@ -36,6 +37,7 @@ class AlbumRow(Gtk.ListBoxRow, TracksView):
                          (GObject.TYPE_PYOBJECT, GObject.TYPE_PYOBJECT)),
         "track-removed": (GObject.SignalFlags.RUN_FIRST, None,
                           (GObject.TYPE_PYOBJECT, GObject.TYPE_PYOBJECT)),
+        "populated": (GObject.SignalFlags.RUN_FIRST, None, ()),
     }
 
     # Update padding in application.css => albumrow
@@ -57,20 +59,22 @@ class AlbumRow(Gtk.ListBoxRow, TracksView):
         else:
             return cover_height + 2
 
-    def __init__(self, album, height, responsive_type):
+    def __init__(self, album, height, responsive_type, reveal):
         """
             Init row widgets
             @param album as Album
             @param height as int
             @param responsive_type as ResponsiveType
+            @param reveal as bool
         """
         Gtk.ListBoxRow.__init__(self)
+        AlbumArtHelper.__init__(self)
         # Later => TracksView.__init__(self)
+        self.__revealer = None
+        self.__reveal = reveal
         self._responsive_widget = None
         self._album = album
         self.__responsive_type = responsive_type
-        self.__score = None
-        self.__cover = None
         self.__play_indicator = None
         self.set_sensitive(False)
         self.get_style_context().add_class("loading")
@@ -85,6 +89,8 @@ class AlbumRow(Gtk.ListBoxRow, TracksView):
         """
         if self.get_child() is not None:
             return
+        AlbumArtHelper.populate(self, ArtSize.MEDIUM, "small-cover-frame",
+                                halign=Gtk.Align.FILL)
         self.get_style_context().remove_class("loading")
         self.get_style_context().add_class("albumrow")
         self.set_sensitive(True)
@@ -105,14 +111,7 @@ class AlbumRow(Gtk.ListBoxRow, TracksView):
         self.__artist_label.set_ellipsize(Pango.EllipsizeMode.END)
         self.__title_label = Gtk.Label.new(self._album.name)
         self.__title_label.set_ellipsize(Pango.EllipsizeMode.END)
-        self.__cover = Gtk.Image()
-        self.__cover.get_style_context().add_class("small-cover-frame")
-        surface = App().art.get_album_artwork(
-            self._album,
-            ArtSize.MEDIUM,
-            self.get_scale_factor())
-        self.__cover.set_from_surface(surface)
-        self.__cover.set_size_request(ArtSize.MEDIUM, ArtSize.MEDIUM)
+        AlbumArtHelper.set_artwork(self)
         self.__play_indicator = Gtk.Image.new_from_icon_name(
             "media-playback-start-symbolic",
             Gtk.IconSize.MENU)
@@ -132,19 +131,38 @@ class AlbumRow(Gtk.ListBoxRow, TracksView):
             self.__action_button.get_style_context().add_class(
                 "track-menu-button")
             self.__action_button.set_property("valign", Gtk.Align.CENTER)
-            self.__action_button.connect("clicked", self.__on_action_clicked)
+            self.__action_button.connect("clicked",
+                                         self.__on_action_button_clicked)
+        self.__artists_button = None
+        if self.__responsive_type == ResponsiveType.SEARCH:
+            self.__artists_button = Gtk.Button.new_from_icon_name(
+                    'avatar-default-symbolic',
+                    Gtk.IconSize.MENU)
+            self.__artists_button.set_relief(Gtk.ReliefStyle.NONE)
+            self.__artists_button.get_style_context().add_class(
+                "album-menu-button")
+            self.__artists_button.set_tooltip_text(_("Go to artist view"))
+            self.__artists_button.set_property("valign", Gtk.Align.CENTER)
+            self.__artists_button.connect("clicked",
+                                          self.__on_artists_button_clicked)
         vgrid = Gtk.Grid()
         vgrid.set_column_spacing(5)
         vgrid.add(self.__play_indicator)
         vgrid.add(self.__title_label)
-        grid.attach(self.__artist_label, 1, 0, 1, 1)
+        index = 1
+        grid.attach(self.__artist_label, index, 0, 1, 1)
+        index += 1
+        if self.__artists_button is not None:
+            grid.attach(self.__artists_button, index, 0, 1, 2)
+            index += 1
         if self.__action_button is not None:
-            grid.attach(self.__action_button, 2, 0, 1, 2)
-        grid.attach(self.__cover, 0, 0, 1, 2)
+            grid.attach(self.__action_button, index, 0, 1, 2)
+            index += 1
+        grid.attach(self._artwork, 0, 0, 1, 2)
         grid.attach(vgrid, 1, 1, 1, 1)
         self.__revealer = Gtk.Revealer.new()
         self.__revealer.show()
-        grid.attach(self.__revealer, 0, 2, 3, 1)
+        grid.attach(self.__revealer, 0, 2, index, 1)
         row_widget.add(grid)
         self.add(row_widget)
         self.set_playing_indicator()
@@ -155,13 +173,14 @@ class AlbumRow(Gtk.ListBoxRow, TracksView):
         self.drag_dest_set(Gtk.DestDefaults.DROP,
                            [], Gdk.DragAction.MOVE)
         self.drag_dest_add_text_targets()
+        self.set_selection()
         self.connect("drag-begin", self.__on_drag_begin)
         self.connect("drag-data-get", self.__on_drag_data_get)
         self.connect("drag-data-received", self.__on_drag_data_received)
         self.connect("drag-leave", self.__on_drag_leave)
         self.connect("button-release-event", self.__on_button_release_event)
-        if len(self._album.tracks) != self._album.tracks_count:
-            self.__on_button_release_event(self, None)
+        if self.__reveal:
+            self.reveal()
 
     def reveal(self, reveal=None,
                transition_type=Gtk.RevealerTransitionType.SLIDE_DOWN):
@@ -209,34 +228,27 @@ class AlbumRow(Gtk.ListBoxRow, TracksView):
         """
             Update widget state
         """
-        child = self.get_child()
-        if child is None:
-            return
         selected = self._album.id == App().player.current_track.album.id
-        style_context = child.get_style_context()
-        revealed = self.__revealer.get_reveal_child()
+        revealed = self.__revealer is not None and\
+            self.__revealer.get_reveal_child()
         if selected and not revealed:
-            style_context.add_class("album-row-selected")
+            self.set_state(Gtk.StateType.SELECTED)
         elif not selected or revealed:
-            style_context.remove_class("album-row-selected")
-
-    def set_artwork(self, album_id):
-        """
-            Update cover for current album
-            @param album_id as int
-        """
-        if self.__cover is None or album_id != self._album.id:
-            return
-        surface = App().art.get_album_artwork(
-            self._album,
-            ArtSize.MEDIUM,
-            self.get_scale_factor())
-        self.__cover.set_from_surface(surface)
+            self.set_state(Gtk.StateType.NORMAL)
 
     def stop(self):
         """
             Stop view loading
         """
+        # FIXME
+
+    @property
+    def is_populated(self):
+        """
+            Return True if populated
+            @return bool
+        """
+        return True
 
     @property
     def album(self):
@@ -322,7 +334,7 @@ class AlbumRow(Gtk.ListBoxRow, TracksView):
         self.get_style_context().remove_class("drag-up")
         self.get_style_context().remove_class("drag-down")
 
-    def __on_action_clicked(self, button):
+    def __on_action_button_clicked(self, button):
         """
             ResponsiveType.SEARCH: Play album
             Else: Delete album
@@ -347,6 +359,16 @@ class AlbumRow(Gtk.ListBoxRow, TracksView):
                 App().player.remove_album(self._album)
             self.destroy()
 
+    def __on_artists_button_clicked(self, button):
+        """
+            Jump to artists albums view
+            @param button as Gtk.Button
+        """
+        popover = self.get_ancestor(Gtk.Popover)
+        if popover is not None:
+            popover.popdown()
+        App().window.container.show_artists_albums(self._album.artist_ids)
+
     def __on_query_tooltip(self, widget, x, y, keyboard, tooltip):
         """
             Show tooltip if needed
@@ -380,6 +402,7 @@ class AlbumsListView(LazyLoadingView, ViewController):
         ViewController.__init__(self)
         self.__responsive_type = responsive_type
         self.__autoscroll_timeout_id = None
+        self.__reveals = []
         self.__prev_animated_rows = []
         # Calculate default album height based on current pango context
         # We may need to listen to screen changes
@@ -401,6 +424,13 @@ class AlbumsListView(LazyLoadingView, ViewController):
         self.connect_current_changed_signal()
         self.connect_artwork_changed_signal("album")
 
+    def set_reveal(self, album_ids):
+        """
+            Set albums to reveal on populate
+            @param album_ids as [int]s
+        """
+        self.__reveals = album_ids
+
     def populate(self, albums):
         """
             Populate widget with album rows
@@ -497,7 +527,8 @@ class AlbumsListView(LazyLoadingView, ViewController):
             @param album_id as int
         """
         for child in self.__view.get_children():
-            child.set_artwork(album_id)
+            if child.album.id == album_id:
+                child.set_artwork()
 
 #######################
 # PRIVATE             #
@@ -519,7 +550,7 @@ class AlbumsListView(LazyLoadingView, ViewController):
             return
         if albums:
             album = albums.pop(0)
-            row = self.__row_for_album(album)
+            row = self.__row_for_album(album, album.id in self.__reveals)
             row.show()
             self.__view.add(row)
             self._lazy_queue.append(row)
@@ -537,12 +568,13 @@ class AlbumsListView(LazyLoadingView, ViewController):
             if self._viewport.get_child() is None:
                 self._viewport.add(self.__view)
 
-    def __row_for_album(self, album):
+    def __row_for_album(self, album, reveal=False):
         """
             Get a row for track id
             @param album as Album
+            @param reveal as bool
         """
-        row = AlbumRow(album, self.__height, self.__responsive_type)
+        row = AlbumRow(album, self.__height, self.__responsive_type, reveal)
         row.connect("destroy", self.__on_child_destroyed)
         row.connect("track-moved", self.__on_track_moved)
         row.connect("album-moved", self.__on_album_moved)
