@@ -84,8 +84,14 @@ class DeviceView(View):
         self.__syncing_btn.set_label(_("Synchronize %s") % "")
         builder.connect_signals(self)
         self.__device_widget = DeviceManagerWidget(self)
-        self.__device_widget.connect("sync-finished", self.__on_sync_finished)
+        self.__device_widget.mtp_sync.connect("sync-finished",
+                                              self.__on_sync_finished)
+        self.__device_widget.mtp_sync.connect("sync-errors",
+                                              self.__on_sync_errors)
         self.__device_widget.show()
+        self.__infobar = builder.get_object("infobar")
+        self.__error_label = builder.get_object("error_label")
+
         grid = builder.get_object("device")
         self.add(grid)
         self.add(self._scrolled)
@@ -123,7 +129,7 @@ class DeviceView(View):
             Check if lollypop is syncing
             @return bool
         """
-        return self.__device_widget.is_syncing()
+        return not self.__device_widget.mtp_sync.cancellable.is_cancelled()
 
     @property
     def device(self):
@@ -136,6 +142,17 @@ class DeviceView(View):
 #######################
 # PROTECTED           #
 #######################
+    def _on_infobar_response(self, infobar, response_id):
+        """
+            Hide infobar
+            @param widget as Gtk.Infobar
+            @param reponse id as int
+        """
+        if response_id == Gtk.ResponseType.CLOSE:
+            self.__infobar.set_revealed(False)
+            # WTF?
+            GLib.timeout_add(300, self.__infobar.hide)
+
     def _on_destroy(self, widget):
         """
             Remove running timeout
@@ -151,8 +168,8 @@ class DeviceView(View):
             Start synchronisation
             @param widget as Gtk.Button
         """
-        if self.__device_widget.is_syncing():
-            self.__device_widget.cancel_sync()
+        if not self.__device_widget.mtp_sync.cancellable.is_cancelled():
+            self.__device_widget.mtp_sync.cancellable.cancel()
         elif not App().window.container.progress.is_visible():
             self.__memory_combo.hide()
             self.__syncing_btn.set_label(_("Cancel synchronization"))
@@ -191,11 +208,20 @@ class DeviceView(View):
         self.__device.uri = uri
 
     def stop(self):
-        """
-            Stop syncing
-        """
         pass
 
+    def __on_sync_errors(self, mtp_sync, error):
+        """
+            Show information bar with error message
+            @param mtp_sync as MtpSync
+            @param error as str
+        """
+        error_text = error or _("Unknown error while syncing,"
+                                " try to reboot your device")
+        self.__error_label.set_text(error_text)
+        self.__infobar.show()
+        self.__infobar.set_revealed(True)
+
     def __on_sync_finished(self, device_widget):
         """
             Restore widgets state
@@ -212,7 +238,7 @@ class DeviceView(View):
         """
         # Just update device widget if already populated
         if self.__memory_combo.get_active_text() is not None:
-            if not self.__device_widget.is_syncing():
+            if self.__device_widget.mtp_sync.cancellable.is_cancelled():
                 self.__device_widget.populate(self.__selected_ids)
             return
         for text in text_list:
