@@ -16,12 +16,12 @@ from gettext import gettext as _
 
 from lollypop.view import View
 from lollypop.define import App, WindowSize, Type
-from lollypop.controllers import InfoController
+from lollypop.controller_information import InformationController
 from lollypop.utils import escape
 from lollypop.helper_task import TaskHelper
 
 
-class LyricsView(View, InfoController):
+class LyricsView(View, InformationController):
     """
         Show lyrics for track
     """
@@ -31,7 +31,8 @@ class LyricsView(View, InfoController):
             Init view
         """
         View.__init__(self)
-        InfoController.__init__(self, False)
+        InformationController.__init__(self, False)
+        self.__current_changed_id = None
         self.__size_allocate_timeout_id = None
         self.__downloads_running = 0
         self.__lyrics_set = False
@@ -45,6 +46,8 @@ class LyricsView(View, InfoController):
         self.__translate_button = builder.get_object("translate_button")
         self.add(builder.get_object("widget"))
         self.connect("size-allocate", self.__on_size_allocate)
+        self.connect("map", self.__on_map)
+        self.connect("unmap", self.__on_unmap)
 
     def populate(self, track):
         """
@@ -82,14 +85,6 @@ class LyricsView(View, InfoController):
 ##############
 # PROTECTED  #
 ##############
-    def _on_current_changed(self, player):
-        """
-            Update lyrics
-            @param player as Player
-        """
-        self.populate(App().player.current_track)
-        self.__translate_button.set_sensitive(True)
-
     def _on_close_clicked(self, button):
         """
             Close lyrics view
@@ -253,3 +248,26 @@ class LyricsView(View, InfoController):
                 pass
         if not self.__lyrics_set and self.__downloads_running == 0:
             self.__lyrics_label.set_text(_("No lyrics found ") + "😐")
+
+    def __on_current_changed(self, player):
+        """
+            Update lyrics
+            @param player as Player
+        """
+        self.populate(App().player.current_track)
+        self.__translate_button.set_sensitive(True)
+
+    def __on_map(self, widget):
+        """
+            Connect player signal
+        """
+        self.__current_changed_id = App().player.connect(
+            "current-changed", self.__on_current_changed)
+
+    def __on_unmap(self, widget):
+        """
+            Connect player signal
+        """
+        if self.__current_changed_id is not None:
+            App().player.disconnect(self.__current_changed_id)
+            self.__current_changed_id = None
