@@ -18,7 +18,7 @@ from lollypop.define import WindowSize, Loading
 from lollypop.widgets_track import TracksWidget, TrackRow
 from lollypop.objects import Album
 from lollypop.logger import Logger
-from lollypop.define import App, Type, ResponsiveType, Shuffle, NextContext
+from lollypop.define import App, Type, Shuffle, NextContext, ResponsiveType
 
 
 class TracksView:
@@ -61,7 +61,10 @@ class TracksView:
         if self._responsive_type in [ResponsiveType.DND,
                                      ResponsiveType.LIST,
                                      ResponsiveType.SEARCH]:
+            album = Album(self._album.id)
+            album.set_tracks(self._album.tracks)
             self._album.merge_discs()
+
         # Discs to load, will be emptied
         self.__discs = list(self._album.discs)
         for disc in self.__discs:
@@ -273,6 +276,14 @@ class TracksView:
             boxes.append(widget)
         return boxes
 
+    @property
+    def discs(self):
+        """
+            Get widget discs
+            @return [Discs]
+        """
+        return self.__discs
+
     @property
     def is_populated(self):
         """
