@@ -62,13 +62,6 @@ class AlbumBaseWidget:
             self._timeout_id = None
         self._show_overlay_func(set)
 
-    @property
-    def is_populated(self):
-        """
-            True if album populated
-        """
-        return True
-
     @property
     def filter(self):
         return ""
@@ -85,7 +78,7 @@ class AlbumBaseWidget:
         """
             True if overlayed or going to be
         """
-        return self._show_overlay or self._timeout_id is not None
+        return self._show_overlay
 
 #######################
 # PROTECTED           #
